{% for c in len(project.name) %}
*
{% endfor %}
{{ project.name }}
{% for c in len(project.name) %}
*
{% endfor %}

.. image:: https://raw.githubusercontent.com/sigstore/community/main/artwork/badge/sigstore_codesigned_purple.png
 :align: right
 :height: 140
 :target: https://www.sigstore.dev/
